@@ -1,17 +1,19 @@
 from datetime import datetime
 from couchdbcurl.client import Document
-from django.conf import settings
 
-from django.contrib.auth.models import get_hexdigest
 
 class User(Document):
 
     def is_active(self):
-        """Fake function"""
+        """Fake function. Always returns True"""
         return True
 
     def is_authenticated(self):
-        """Fake function"""
+        """Links to self.is_superuser"""
+        return self.is_superuser
+
+    def is_staff(self):
+        """Fake function. Always returns True"""
         return True
 
     def get_and_delete_messages(self):
@@ -22,6 +24,8 @@ class User(Document):
         pass
 
     def save(self, *args, **kwargs):
+        """Save user object and update ``last_login`` field"""
+        
         if hasattr(self, 'backend'):
             backend = self.backend
             del(self.backend)
@@ -29,6 +33,7 @@ class User(Document):
             backend = None
             
         if hasattr(self, 'last_login') and type(self.last_login) == datetime:
+            from django.conf import settings
             self.last_login = self.last_login.strftime(settings.DATETIME_FMT)
 
         Document.save(self, *args, **kwargs)
@@ -40,6 +45,8 @@ class User(Document):
         """This is copy-paste from django.contrib.auth.models.User.set_password()"""
         
         import random
+        from django.contrib.auth.models import get_hexdigest
+        
         algo = 'sha1'
         salt = get_hexdigest(algo, str(random.random()), str(random.random()))[:5]
         hsh = get_hexdigest(algo, salt, raw_password)
